# History

### 3.5.0 (2020-03-03)

* Add XML export capability to the GUI
* Warn user about unsaved data
* Clear GUI and reload file after save
* Add XMP Creator field
* bwf2csv can now validate MD5 of data chunk
* Other minor improvements and bug fixes

### 3.4.0 (2019-12-14)

* Add capability to toggle between existing, tempate, and edited metadata
* Add IARL
* Add additional XMP MD fields
* Add bwf2pbcore and bwf2csv tools


### 3.3.1 (2019-07-22)

* Add "--config" argument to autoBWF
* Create expanded documentation in Sphinx and host on readthedocs

### 3.3.0 (2019-06-24)

* Add "quit" option to completion message box
* Add progress indicator screen
* Change ``autolame`` usage to allow for multiple inputs and globbing

### 3.2.1 (2019-06-22)

* Fixed bug that was resulting in the overwriting of metadata in template files (and other issues).

### 3.2.0 (2019-05-14)

* Major rearrangment for packaging purposes.
* First release on PyPI.
